@@ -120,7 +120,7 @@ sub _groups {
             [ 'video_dir',         "- Main video directory" ],
             [ 'use_extractor_dir', "- Extractor directory"  ],
             [ 'use_uploader_dir',  "- Uploader directory"   ],
-            [ 'filename_format',   "- Filename: fmt info"   ],
+            [ 'filename_format',   "- Filename format info" ],
         ],
         group_quality => [
             [ 'quality',             "- Resolution"          ],
